@@ -14,10 +14,10 @@ our $CLASS_INFOS;
 # Classes which need to build
 our @BUILD_NEED_CLASSES;
 
-# Already build class;
+# Already built classes;
 our %ALREADY_BUILD_CLASSES;
  
-# Attribute infomation resisted by MODIFY_CODE_ATTRIBUTES handler
+# Attribute information resisted by MODIFY_CODE_ATTRIBUTES handler
 our @ACCESSOR_INFOS;
  
 # Valid import option
@@ -386,32 +386,38 @@ sub delete_class_attr { Util->delete_class_attr(@_) }
 
 =head1 NAME
  
-Object::Simple - Simple class builder
+Object::Simple - a simple class builder
  
 =head1 VERSION
 
-Version 2.1101
+Version 2.1201
 
 =cut
 
-our $VERSION = '2.1101';
+our $VERSION = '2.1201';
  
 =head1 FEATURES
  
 =over 4
  
-=item 1. You can define accessors in very simple way.
+=item 1. You can define accessors in a very simple way.
  
-=item 2. new method is prepared.
+=item 2. The "new()" method is already defined.
  
-=item 3. You can define variouse accessor option(default, type, chained, weak)
+=item 3. You can define various accessor option (default, type, chained, weak).
 
-=item 4. you can use Mixin system like Ruby
+=item 4. you can use a mixin system like Ruby's.
  
 =back
  
-If you use Object::Simple, you are free from bitter work 
-writing new and accessors repeatedly.
+By using Object::Simple, you will be exempt from the bitter work of
+repeatedly writing the new() constructor and the accessors.
+
+But I recommend now L<Object::Simple::Base> than L<Object::Simple>.
+
+It is more Object Oriented, more simple and easier.
+
+See L<Object::Simple::Base>
 
 =cut
  
@@ -425,7 +431,8 @@ writing new and accessors repeatedly.
     sub author : Attr {}
     sub price  : Attr {}
     
-    Object::Simple->build_class; # End of module. Don't forget to call 'build_class' method
+    Object::Simple->build_class; 
+    # End of module. Don't forget to call 'build_class' method
     
     # Using class
     use Book;
@@ -487,21 +494,21 @@ writing new and accessors repeatedly.
     );
 
 =cut
- 
+
 =head1 Methods
  
 =head2 new
 
-Object::Simple prepare 'new' method for subclass.
-So you do not have to define 'new'.
-'new' can receive hash or hash reference
+Object::Simple defines a 'new' method for the subclass, so you do not need
+to define 'new'. 'new' accepts a hash or a hash reference.
 
     $book = Book->new(title => 'Good life', author => 'Ken', price => 200);
     $book = Book->new({title => 'Good life', author => 'Ken', price => 200});
 
-You can also override 'new' for initialize or arrange of arguments.
+You can also override 'new' for finer-grained initialization or arranging
+the arguments.
 
-The following is initializing sample.
+The following is an initialization sample.
 
     sub new {
         my $self = shift->SUPER::new(@_);
@@ -517,7 +524,7 @@ The following is initializing sample.
         # write what you want
     }
     
-The following is arange of argument sample
+The following sample arranges the arguments differently:
 
     sub new {
         my ($class, $title, $author) = @_;
@@ -530,7 +537,8 @@ The following is arange of argument sample
  
 =head2 build_class
 
-You must call build_class at end of script. Class is build completely by this method.
+You must call build_class at the end of the package. The class will be 
+completely constructed by this invocation.
 
     Object::Simple->build_class;
 
@@ -1079,7 +1087,7 @@ Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
  
 Github L<http://github.com/yuki-kimoto/>
 
-I develope this module at L<http://github.com/yuki-kimoto/object-simple>
+I develop this module at L<http://github.com/yuki-kimoto/object-simple> .
 
 Please tell me bug if you find.
 
